==> wle_0.7-3.tar.gz: wle/data/artificial.R <==
artificial <- matrix(c(10.1,  19.6,  28.3,   9.7,
 9.5,  20.5,  28.9,  10.1,
10.7,  20.2,  31.0,  10.3,
 9.9,  21.5,  31.7,   9.5,
10.3,  21.1,  31.1,  10.0,
10.8,  20.4,  29.2,  10.0,
10.5,  20.9,  29.1,  10.8,
 9.9,  19.6,  28.8,  10.3,
 9.7,  20.7,  31.0,   9.6,
 9.3,  19.7,  30.3,   9.9,
11.0,  24.0,  35.0,  -0.2,
12.0,  23.0,  37.0,  -0.4,
12.0,  26.0,  34.0,   0.7,
11.0,  34.0,  34.0,   0.1,
 3.4,   2.9,   2.1,  -0.4,
 3.1,   2.2,   0.3,   0.6,
 0.0,   1.6,   0.2,  -0.2,
 2.3,   1.6,   2.0,   0.0,
 0.8,   2.9,   1.6,   0.1,
 3.1,   3.4,   2.2,   0.4,
 2.6,   2.2,   1.9,   0.9,
 0.4,   3.2,   1.9,   0.3,
 2.0,   2.3,   0.8,  -0.8,
 1.3,   2.3,   0.5,   0.7,
 1.0,   0.0,   0.4,  -0.3,
 0.9,   3.3,   2.5,  -0.8,
 3.3,   2.5,   2.9,  -0.7,
 1.8,   0.8,   2.0,   0.3,
 1.2,   0.9,   0.8,   0.3,
 1.2,   0.7,   3.4,  -0.3,
 3.1,   1.4,   1.0,   0.0,
 0.5,   2.4,   0.3,  -0.4,
 1.5,   3.1,   1.5,  -0.6,
 0.4,   0.0,   0.7,  -0.7,
 3.1,   2.4,   3.0,   0.3,
 0.1,   2.2,   2.7,  -1.0,
 0.1,   3.0,   2.6,  -0.6,
 1.5,   1.2,   0.2,   0.9,
 2.1,   0.0,   1.2,  -0.7,
 0.5,   2.0,   1.2,  -0.5,
 3.4,   1.6,   2.9,  -0.1,
 0.3,   1.0,   2.7,  -0.7,
 0.1,   3.3,   0.9,   0.6,
 1.8,   0.5,   3.2,  -0.7,
 1.9,   0.1,   0.6,  -0.5,
 1.8,   0.5,   3.0,  -0.4,
 3.0,   0.1,   0.8,  -0.9,
 3.1,   1.6,   3.0,   0.1,
 3.1,   2.5,   1.9,   0.9,
 2.1,   2.8,   2.9,  -0.4,
 2.3,   1.5,   0.4,   0.7,
 3.3,   0.6,   1.2,  -0.5,
 0.3,   0.4,   3.3,   0.7,
 1.1,   3.0,   0.3,   0.7,
 0.5,   2.4,   0.9,   0.0,
 1.8,   3.2,   0.9,   0.1,
 1.8,   0.7,   0.7,   0.7,
 2.4,   3.4,   1.5,  -0.1,
 1.6,   2.1,   3.0,  -0.3,
 0.3,   1.5,   3.3,  -0.9,
 0.4,   3.4,   3.0,  -0.3,
 0.9,   0.1,   0.3,   0.6,
 1.1,   2.7,   0.2,  -0.3,
 2.8,   3.0,   2.9,  -0.5,
 2.0,   0.7,   2.7,   0.6,
 0.2,   1.8,   0.8,  -0.9,
 1.6,   2.0,   1.2,  -0.7,
 0.1,   0.0,   1.1,   0.6,
 2.0,   0.6,   0.3,   0.2,
 1.0,   2.2,   2.9,   0.7,
 2.2,   2.5,   2.3,   0.2,
 0.6,   2.0,   1.5,  -0.2,
 0.3,   1.7,   2.2,   0.4,
 0.0,   2.2,   1.6,  -0.9,
 0.3,   0.4,   2.6,   0.2), ncol=4, byrow=TRUE)

y.artificial <- artificial[,4]
x.artificial <- artificial[,1:3]

==> wle_0.7-9.tar.gz: wle/data/artificial.R <==
artificial <- matrix(c(10.1,  19.6,  28.3,   9.7,
 9.5,  20.5,  28.9,  10.1,
10.7,  20.2,  31.0,  10.3,
 9.9,  21.5,  31.7,   9.5,
10.3,  21.1,  31.1,  10.0,
10.8,  20.4,  29.2,  10.0,
10.5,  20.9,  29.1,  10.8,
 9.9,  19.6,  28.8,  10.3,
 9.7,  20.7,  31.0,   9.6,
 9.3,  19.7,  30.3,   9.9,
11.0,  24.0,  35.0,  -0.2,
12.0,  23.0,  37.0,  -0.4,
12.0,  26.0,  34.0,   0.7,
11.0,  34.0,  34.0,   0.1,
 3.4,   2.9,   2.1,  -0.4,
 3.1,   2.2,   0.3,   0.6,
 0.0,   1.6,   0.2,  -0.2,
 2.3,   1.6,   2.0,   0.0,
 0.8,   2.9,   1.6,   0.1,
 3.1,   3.4,   2.2,   0.4,
 2.6,   2.2,   1.9,   0.9,
 0.4,   3.2,   1.9,   0.3,
 2.0,   2.3,   0.8,  -0.8,
 1.3,   2.3,   0.5,   0.7,
 1.0,   0.0,   0.4,  -0.3,
 0.9,   3.3,   2.5,  -0.8,
 3.3,   2.5,   2.9,  -0.7,
 1.8,   0.8,   2.0,   0.3,
 1.2,   0.9,   0.8,   0.3,
 1.2,   0.7,   3.4,  -0.3,
 3.1,   1.4,   1.0,   0.0,
 0.5,   2.4,   0.3,  -0.4,
 1.5,   3.1,   1.5,  -0.6,
 0.4,   0.0,   0.7,  -0.7,
 3.1,   2.4,   3.0,   0.3,
 0.1,   2.2,   2.7,  -1.0,
 0.1,   3.0,   2.6,  -0.6,
 1.5,   1.2,   0.2,   0.9,
 2.1,   0.0,   1.2,  -0.7,
 0.5,   2.0,   1.2,  -0.5,
 3.4,   1.6,   2.9,  -0.1,
 0.3,   1.0,   2.7,  -0.7,
 0.1,   3.3,   0.9,   0.6,
 1.8,   0.5,   3.2,  -0.7,
 1.9,   0.1,   0.6,  -0.5,
 1.8,   0.5,   3.0,  -0.4,
 3.0,   0.1,   0.8,  -0.9,
 3.1,   1.6,   3.0,   0.1,
 3.1,   2.5,   1.9,   0.9,
 2.1,   2.8,   2.9,  -0.4,
 2.3,   1.5,   0.4,   0.7,
 3.3,   0.6,   1.2,  -0.5,
 0.3,   0.4,   3.3,   0.7,
 1.1,   3.0,   0.3,   0.7,
 0.5,   2.4,   0.9,   0.0,
 1.8,   3.2,   0.9,   0.1,
 1.8,   0.7,   0.7,   0.7,
 2.4,   3.4,   1.5,  -0.1,
 1.6,   2.1,   3.0,  -0.3,
 0.3,   1.5,   3.3,  -0.9,
 0.4,   3.4,   3.0,  -0.3,
 0.9,   0.1,   0.3,   0.6,
 1.1,   2.7,   0.2,  -0.3,
 2.8,   3.0,   2.9,  -0.5,
 2.0,   0.7,   2.7,   0.6,
 0.2,   1.8,   0.8,  -0.9,
 1.6,   2.0,   1.2,  -0.7,
 0.1,   0.0,   1.1,   0.6,
 2.0,   0.6,   0.3,   0.2,
 1.0,   2.2,   2.9,   0.7,
 2.2,   2.5,   2.3,   0.2,
 0.6,   2.0,   1.5,  -0.2,
 0.3,   1.7,   2.2,   0.4,
 0.0,   2.2,   1.6,  -0.9,
 0.3,   0.4,   2.6,   0.2), ncol=4, byrow=TRUE)

y.artificial <- artificial[,4]
x.artificial <- artificial[,1:3]

dimnames(artificial) <- list(NULL, c(paste("x", 1:3, sep=""), "y"))
artificial <- as.data.frame(artificial)
